/****************************************************************************
	File: EgConstants.h
	Description: Defines constants for EyeGaze system
	Created: 8/7/2001
	
	Author: Tim Halverson
	Principle Investigator: Anthony Hornof
	Cognitive Modeling and Eye Tracking Lab
	CIS Department
	University of Oregon
	
	Based partly on EgWin.h by LC Technologies.
	
	Copyright (c) 2001 by the University of Oregon.
	ALL RIGHTS RESERVED.

	Permission to use, copy, and distribute this software in
	its entirety for non-commercial purposes and without fee,
	is hereby granted, provided that the above copyright notice
	and this permission notice appear in all copies and their
	documentation.

	Software developers, consultants, or anyone else who wishes
	to use all or part of the software or its documentation for
	commercial purposes should contact the Technology Transfer
	Office at the University of Oregon to arrange a commercial
	license agreement.

	This software is provided "as is" without expressed or
	implied warranty of any kind.

*****************************************************************************/

#ifndef EGCONSTANTS_H
#define EGCONSTANTS_H

// Custom carbon events
const UInt32 egEvent = 474747;	//	Event class id for EyeGaze events
const UInt32 calibrationComplete = 1001;	// Event type for a completed calibration
const UInt32 calibrationAborted = 1002;		// Event type for an aborted calibration
const UInt32 eyeGazeReady = 1003;			// Event type to indicate the server is ready
const UInt32 eyeGazeError = 1004;				// Event type to indicate a communication error with the server.
const UInt32 eyeGazeEnd = 1005;				// Event type to indicate a successful disconnect from the server.

// Communications
const int EG_COMM_TYPE_LOCAL  = 0;    /* Single computer configuration.          */
const int EG_COMM_TYPE_SOCKET = 1;    /* 2 computers, comm over TCP/IP.          */
const int EG_COMM_TYPE_SERIAL = 2;    /* 2 computers, comm over RS-232 serial.   */

const int EG_MESSAGE_TYPE_GAZEINFO       = 0;
const int EG_MESSAGE_TYPE_MOUSEPOSITION  = 1;
const int EG_MESSAGE_TYPE_MOUSEBUTTON    = 2;
const int EG_MESSAGE_TYPE_KEYBD_COMMAND  = 3;
const int EG_MESSAGE_TYPE_MOUSERELATIVE  = 4;

const int EG_MESSAGE_TYPE_CALIBRATE             = 10;
const int EG_MESSAGE_TYPE_WORKSTATION_QUERY     = 11;
const int EG_MESSAGE_TYPE_WORKSTATION_RESPONSE  = 12;
const int EG_MESSAGE_TYPE_CLEAR_SCREEN          = 13;
const int EG_MESSAGE_TYPE_SET_COLOR             = 14;
const int EG_MESSAGE_TYPE_SET_DIAMETER          = 15;
const int EG_MESSAGE_TYPE_DRAW_CIRCLE           = 16;
const int EG_MESSAGE_TYPE_DRAW_CROSS            = 17;
const int EG_MESSAGE_TYPE_DISPLAY_TEXT          = 18;
const int EG_MESSAGE_TYPE_CALIBRATION_COMPLETE  = 19;
const int EG_MESSAGE_TYPE_CALIBRATION_ABORTED   = 20;

const int EG_MESSAGE_TYPE_BEGIN_SENDING_DATA    = 30;
const int EG_MESSAGE_TYPE_STOP_SENDING_DATA     = 31;
const int EG_MESSAGE_TYPE_CLOSE_AND_RECYCLE     = 32;
const int EG_MESSAGE_TYPE_FILE_OPEN             = 33;
const int EG_MESSAGE_TYPE_FILE_WRITE_HEADER     = 34;
const int EG_MESSAGE_TYPE_FILE_APPEND_TEXT      = 35;
const int EG_MESSAGE_TYPE_FILE_START_RECORDING  = 36;
const int EG_MESSAGE_TYPE_FILE_STOP_RECORDING   = 37;
const int EG_MESSAGE_TYPE_FILE_MARK_EVENT       = 38;
const int EG_MESSAGE_TYPE_FILE_CLOSE            = 39;

// RGBColor values
//                          xxBBGGRR
const int BLACK = 0x00000000;
const int BLUE = 0x00aa0000;
const int GREEN = 0x0000aa00;
const int CYAN = 0x00aaaa00;
const int RED = 0x000000aa;
const int MAGENTA = 0x00aa00aa;
const int BROWN = 0x000056aa;
const int WHITE = 0x00aaaaaa;
const int GRAY = 0x00565656;
const int LIGHT_BLUE = 0x00FF5656;
const int LIGHT_GREEN = 0x0056ff56;
const int LIGHT_CYAN = 0x00ffFF56;
const int LIGHT_RED = 0x005656FF;
const int LIGHT_MAGENTA = 0x00ff56ff;
const int YELLOW = 0x0056ffff;
const int BRIGHT_WHITE = 0x00FFFFFF;

// ppat resources - solid colors
const int PPAT_BLACK = 128;
const int PPAT_BLUE = 129;
const int PPAT_GREEN = 130;
const int PPAT_CYAN = 131;
const int PPAT_RED = 132;
const int PPAT_MAGENTA = 133;
const int PPAT_BROWN = 134;
const int PPAT_WHITE = 135;
const int PPAT_GRAY = 136;
const int PPAT_LIGHT_BLUE = 137;
const int PPAT_LIGHT_GREEN = 138;
const int PPAT_LIGHT_CYAN = 139;
const int PPAT_LIGHT_RED = 140;
const int PPAT_LIGHT_MAGENTA = 141;
const int PPAT_YELLOW = 142;
const int PPAT_BRIGHT_WHITE = 143;

// Txtr resources
const int CAL_FONT = 700;

#define EVER ;;

#endif
